from slicemap.slicemap import SliceMap

try:
    import matplotlib.pyplot as plt

    from slicemap.plotting import plot_slicemap
except ImportError:
    pass
